@@ -13,12 +13,11 @@
 #   under the License.
 #
 
-import six
 import time
+from unittest import mock
 import uuid
 
 from cliff import columns as cliff_columns
-import mock
 
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
@@ -32,7 +31,6 @@ DROWSSAP = "dr0w$$aP"
 
 
 class FakeOddballResource(fakes.FakeResource):
-
     def get(self, attr):
         """get() is needed for utils.find_resource()"""
         if attr == 'id':
@@ -44,7 +42,6 @@ class FakeOddballResource(fakes.FakeResource):
 
 
 class TestUtils(test_utils.TestCase):
-
     def _get_test_items(self):
         item1 = {'a': 1, 'b': 2}
         item2 = {'a': 1, 'b': 3}
@@ -131,18 +128,18 @@ class TestUtils(test_utils.TestCase):
         mock_stdin = mock.Mock()
         mock_stdin.isatty = mock.Mock()
         mock_stdin.isatty.return_value = False
-        self.assertRaises(exceptions.CommandError,
-                          utils.get_password,
-                          mock_stdin)
+        self.assertRaises(
+            exceptions.CommandError, utils.get_password, mock_stdin
+        )
 
     def test_get_password_cntrl_d(self):
         with mock.patch("getpass.getpass", side_effect=EOFError()):
             mock_stdin = mock.Mock()
             mock_stdin.isatty = mock.Mock()
             mock_stdin.isatty.return_value = True
-            self.assertRaises(exceptions.CommandError,
-                              utils.get_password,
-                              mock_stdin)
+            self.assertRaises(
+                exceptions.CommandError, utils.get_password, mock_stdin
+            )
 
     def test_sort_items_with_one_key(self):
         items = self._get_test_items()
@@ -188,16 +185,16 @@ class TestUtils(test_utils.TestCase):
     def test_sort_items_with_invalid_key(self):
         items = self._get_test_items()
         sort_str = 'c'
-        self.assertRaises(exceptions.CommandError,
-                          utils.sort_items,
-                          items, sort_str)
+        self.assertRaises(
+            exceptions.CommandError, utils.sort_items, items, sort_str
+        )
 
     def test_sort_items_with_invalid_direction(self):
         items = self._get_test_items()
         sort_str = 'a:bad_dir'
-        self.assertRaises(exceptions.CommandError,
-                          utils.sort_items,
-                          items, sort_str)
+        self.assertRaises(
+            exceptions.CommandError, utils.sort_items, items, sort_str
+        )
 
     def test_sort_items_with_different_type_exception(self):
         item1 = {'a': 2}
@@ -206,11 +203,7 @@ class TestUtils(test_utils.TestCase):
         item4 = {'a': 1}
         items = [item1, item2, item3, item4]
         sort_str = 'a'
-        expect_items = [item3, item4, item1, item2]
-        if six.PY2:
-            self.assertEqual(expect_items, utils.sort_items(items, sort_str))
-        else:
-            self.assertRaises(TypeError, utils.sort_items, items, sort_str)
+        self.assertRaises(TypeError, utils.sort_items, items, sort_str)
 
     def test_sort_items_with_different_type_int(self):
         item1 = {'a': 2}
@@ -221,8 +214,9 @@ class TestUtils(test_utils.TestCase):
         sort_str = 'a'
         sort_type = int
         expect_items = [item3, item4, item1, item2]
-        self.assertEqual(expect_items, utils.sort_items(items, sort_str,
-                                                        sort_type))
+        self.assertEqual(
+            expect_items, utils.sort_items(items, sort_str, sort_type)
+        )
 
     def test_sort_items_with_different_type_str(self):
         item1 = {'a': 'a'}
@@ -233,21 +227,22 @@ class TestUtils(test_utils.TestCase):
         sort_str = 'a'
         sort_type = str
         expect_items = [item3, item2, item1, item4]
-        self.assertEqual(expect_items, utils.sort_items(items, sort_str,
-                                                        sort_type))
+        self.assertEqual(
+            expect_items, utils.sort_items(items, sort_str, sort_type)
+        )
 
     @mock.patch.object(time, 'sleep')
     def test_wait_for_delete_ok(self, mock_sleep):
         # Tests the normal flow that the resource is deleted with a 404 coming
         # back on the 2nd iteration of the wait loop.
         resource = mock.MagicMock(status='ACTIVE', progress=None)
-        mock_get = mock.Mock(side_effect=[resource,
-                                          exceptions.NotFound(404)])
+        mock_get = mock.Mock(side_effect=[resource, exceptions.NotFound(404)])
         manager = mock.MagicMock(get=mock_get)
         res_id = str(uuid.uuid4())
         callback = mock.Mock()
-        self.assertTrue(utils.wait_for_delete(manager, res_id,
-                                              callback=callback))
+        self.assertTrue(
+            utils.wait_for_delete(manager, res_id, callback=callback)
+        )
         mock_sleep.assert_called_once_with(5)
         callback.assert_called_once_with(0)
 
@@ -258,8 +253,9 @@ class TestUtils(test_utils.TestCase):
         mock_get = mock.Mock(return_value=resource)
         manager = mock.MagicMock(get=mock_get)
         res_id = str(uuid.uuid4())
-        self.assertFalse(utils.wait_for_delete(manager, res_id, sleep_time=1,
-                                               timeout=1))
+        self.assertFalse(
+            utils.wait_for_delete(manager, res_id, sleep_time=1, timeout=1)
+        )
         mock_sleep.assert_called_once_with(1)
 
     @mock.patch.object(time, 'sleep')
@@ -279,9 +275,14 @@ class TestUtils(test_utils.TestCase):
         mock_get = mock.Mock(return_value=resource)
         manager = mock.MagicMock(get=mock_get)
         res_id = str(uuid.uuid4())
-        self.assertFalse(utils.wait_for_delete(manager, res_id,
-                                               status_field='my_status',
-                                               error_status=['failed']))
+        self.assertFalse(
+            utils.wait_for_delete(
+                manager,
+                res_id,
+                status_field='my_status',
+                error_status=['failed'],
+            )
+        )
         mock_sleep.assert_not_called()
 
     @mock.patch.object(time, 'sleep')
@@ -290,8 +291,11 @@ class TestUtils(test_utils.TestCase):
         mock_get = mock.Mock(side_effect=Exception)
         manager = mock.MagicMock(get=mock_get)
         res_id = str(uuid.uuid4())
-        self.assertTrue(utils.wait_for_delete(manager, res_id,
-                                              exception_name=['Exception']))
+        self.assertTrue(
+            utils.wait_for_delete(
+                manager, res_id, exception_name=['Exception']
+            )
+        )
         mock_sleep.assert_not_called()
 
     @mock.patch.object(time, 'sleep')
@@ -300,7 +304,12 @@ class TestUtils(test_utils.TestCase):
         resource = mock.MagicMock(status='ACTIVE')
         status_f = mock.Mock(return_value=resource)
         res_id = str(uuid.uuid4())
-        self.assertTrue(utils.wait_for_status(status_f, res_id,))
+        self.assertTrue(
+            utils.wait_for_status(
+                status_f,
+                res_id,
+            )
+        )
         mock_sleep.assert_not_called()
 
     @mock.patch.object(time, 'sleep')
@@ -309,9 +318,14 @@ class TestUtils(test_utils.TestCase):
         resource = mock.MagicMock(my_status='COMPLETE')
         status_f = mock.Mock(return_value=resource)
         res_id = str(uuid.uuid4())
-        self.assertTrue(utils.wait_for_status(status_f, res_id,
-                                              status_field='my_status',
-                                              success_status=['complete']))
+        self.assertTrue(
+            utils.wait_for_status(
+                status_f,
+                res_id,
+                status_field='my_status',
+                success_status=['complete'],
+            )
+        )
         mock_sleep.assert_not_called()
 
     @mock.patch.object(time, 'sleep')
@@ -329,14 +343,20 @@ class TestUtils(test_utils.TestCase):
         resource = mock.MagicMock(my_status='FAILED')
         status_f = mock.Mock(return_value=resource)
         res_id = str(uuid.uuid4())
-        self.assertFalse(utils.wait_for_status(status_f, res_id,
-                                               status_field='my_status',
-                                               error_status=['failed']))
+        self.assertFalse(
+            utils.wait_for_status(
+                status_f,
+                res_id,
+                status_field='my_status',
+                error_status=['failed'],
+            )
+        )
         mock_sleep.assert_not_called()
 
     def test_build_kwargs_dict_value_set(self):
-        self.assertEqual({'arg_bla': 'bla'},
-                         utils.build_kwargs_dict('arg_bla', 'bla'))
+        self.assertEqual(
+            {'arg_bla': 'bla'}, utils.build_kwargs_dict('arg_bla', 'bla')
+        )
 
     def test_build_kwargs_dict_value_None(self):
         self.assertEqual({}, utils.build_kwargs_dict('arg_bla', None))
@@ -354,21 +374,17 @@ class TestUtils(test_utils.TestCase):
         self.assertEqual("999", utils.format_size(999))
         self.assertEqual("100K", utils.format_size(100000))
         self.assertEqual("2M", utils.format_size(2000000))
-        self.assertEqual(
-            "16.4M", utils.format_size(16361280)
-        )
-        self.assertEqual(
-            "1.6G", utils.format_size(1576395005)
-        )
+        self.assertEqual("16.4M", utils.format_size(16361280))
+        self.assertEqual("1.6G", utils.format_size(1576395005))
         self.assertEqual("0", utils.format_size(None))
 
     def test_backward_compat_col_lister(self):
         fake_col_headers = ['ID', 'Name', 'Size']
         columns = ['Display Name']
         column_map = {'Display Name': 'Name'}
-        results = utils.backward_compat_col_lister(fake_col_headers,
-                                                   columns,
-                                                   column_map)
+        results = utils.backward_compat_col_lister(
+            fake_col_headers, columns, column_map
+        )
         self.assertIsInstance(results, list)
         self.assertIn('Display Name', results)
         self.assertNotIn('Name', results)
@@ -379,9 +395,9 @@ class TestUtils(test_utils.TestCase):
         fake_col_headers = ['ID', 'Name', 'Size']
         columns = []
         column_map = {'Display Name': 'Name'}
-        results = utils.backward_compat_col_lister(fake_col_headers,
-                                                   columns,
-                                                   column_map)
+        results = utils.backward_compat_col_lister(
+            fake_col_headers, columns, column_map
+        )
         self.assertIsInstance(results, list)
         self.assertNotIn('Display Name', results)
         self.assertIn('Name', results)
@@ -392,9 +408,9 @@ class TestUtils(test_utils.TestCase):
         fake_col_headers = ('ID', 'Name', 'Size')
         columns = ['Display Name']
         column_map = {'Display Name': 'Name'}
-        results = utils.backward_compat_col_lister(fake_col_headers,
-                                                   columns,
-                                                   column_map)
+        results = utils.backward_compat_col_lister(
+            fake_col_headers, columns, column_map
+        )
         self.assertIsInstance(results, list)
         self.assertIn('Display Name', results)
         self.assertNotIn('Name', results)
@@ -402,14 +418,16 @@ class TestUtils(test_utils.TestCase):
         self.assertIn('Size', results)
 
     def test_backward_compat_col_showone(self):
-        fake_object = {'id': 'fake-id',
-                       'name': 'fake-name',
-                       'size': 'fake-size'}
+        fake_object = {
+            'id': 'fake-id',
+            'name': 'fake-name',
+            'size': 'fake-size',
+        }
         columns = ['display_name']
         column_map = {'display_name': 'name'}
-        results = utils.backward_compat_col_showone(fake_object,
-                                                    columns,
-                                                    column_map)
+        results = utils.backward_compat_col_showone(
+            fake_object, columns, column_map
+        )
         self.assertIsInstance(results, dict)
         self.assertIn('display_name', results)
         self.assertIn('id', results)
@@ -417,14 +435,16 @@ class TestUtils(test_utils.TestCase):
         self.assertIn('size', results)
 
     def test_backward_compat_col_showone_no_specify_column(self):
-        fake_object = {'id': 'fake-id',
-                       'name': 'fake-name',
-                       'size': 'fake-size'}
+        fake_object = {
+            'id': 'fake-id',
+            'name': 'fake-name',
+            'size': 'fake-size',
+        }
         columns = []
         column_map = {'display_name': 'name'}
-        results = utils.backward_compat_col_showone(fake_object,
-                                                    columns,
-                                                    column_map)
+        results = utils.backward_compat_col_showone(
+            fake_object, columns, column_map
+        )
         self.assertIsInstance(results, dict)
         self.assertNotIn('display_name', results)
         self.assertIn('id', results)
@@ -434,8 +454,9 @@ class TestUtils(test_utils.TestCase):
     def _test_get_item_properties_with_formatter(self, formatters):
         names = ('id', 'attr')
         item = fakes.FakeResource(info={'id': 'fake-id', 'attr': ['a', 'b']})
-        res_id, res_attr = utils.get_item_properties(item, names,
-                                                     formatters=formatters)
+        res_id, res_attr = utils.get_item_properties(
+            item, names, formatters=formatters
+        )
         self.assertEqual('fake-id', res_id)
         return res_attr
 
@@ -452,8 +473,9 @@ class TestUtils(test_utils.TestCase):
     def _test_get_dict_properties_with_formatter(self, formatters):
         names = ('id', 'attr')
         item = {'id': 'fake-id', 'attr': ['a', 'b']}
-        res_id, res_attr = utils.get_dict_properties(item, names,
-                                                     formatters=formatters)
+        res_id, res_attr = utils.get_dict_properties(
+            item, names, formatters=formatters
+        )
         self.assertEqual('fake-id', res_id)
         return res_attr
 
@@ -467,14 +489,16 @@ class TestUtils(test_utils.TestCase):
         res_attr = self._test_get_dict_properties_with_formatter(formatters)
         self.assertIsInstance(res_attr, format_columns.ListColumn)
 
-    def _test_calculate_header_and_attrs(self, parsed_args_columns,
-                                         expected_headers, expected_attrs):
+    def _test_calculate_header_and_attrs(
+        self, parsed_args_columns, expected_headers, expected_attrs
+    ):
         column_headers = ('ID', 'Name', 'Fixed IP Addresses')
         columns = ('id', 'name', 'fixed_ips')
         parsed_args = mock.Mock()
         parsed_args.columns = parsed_args_columns
         ret_headers, ret_attrs = utils.calculate_header_and_attrs(
-            column_headers, columns, parsed_args)
+            column_headers, columns, parsed_args
+        )
         self.assertEqual(expected_headers, ret_headers)
         self.assertEqual(expected_attrs, ret_attrs)
         if parsed_args_columns:
@@ -486,25 +510,27 @@ class TestUtils(test_utils.TestCase):
         self._test_calculate_header_and_attrs(
             [],
             ('ID', 'Name', 'Fixed IP Addresses'),
-            ('id', 'name', 'fixed_ips'))
+            ('id', 'name', 'fixed_ips'),
+        )
 
     def test_calculate_header_and_attrs_with_known_columns(self):
         self._test_calculate_header_and_attrs(
-            ['Name', 'ID'],
-            ['Name', 'ID'],
-            ['name', 'id'])
+            ['Name', 'ID'], ['Name', 'ID'], ['name', 'id']
+        )
 
     def test_calculate_header_and_attrs_with_unknown_columns(self):
         self._test_calculate_header_and_attrs(
             ['Name', 'ID', 'device_id'],
             ['Name', 'ID', 'device_id'],
-            ['name', 'id', 'device_id'])
+            ['name', 'id', 'device_id'],
+        )
 
     def test_calculate_header_and_attrs_with_attrname_columns(self):
         self._test_calculate_header_and_attrs(
             ['name', 'id', 'device_id'],
             ['Name', 'ID', 'device_id'],
-            ['name', 'id', 'device_id'])
+            ['name', 'id', 'device_id'],
+        )
 
     def test_subtest(self):
         for i in range(3):
@@ -517,7 +543,6 @@ class NoUniqueMatch(Exception):
 
 
 class TestFindResource(test_utils.TestCase):
-
     def setUp(self):
         super(TestFindResource, self).setUp()
         self.name = 'legos'
@@ -577,36 +602,39 @@ class TestFindResource(test_utils.TestCase):
         self.manager.find = mock.Mock(
             side_effect=exceptions.NotFound(404, "2")
         )
-        result = self.assertRaises(exceptions.CommandError,
-                                   utils.find_resource,
-                                   self.manager,
-                                   self.name)
-        self.assertEqual("No lego with a name or ID of 'legos' exists.",
-                         str(result))
+        result = self.assertRaises(
+            exceptions.CommandError,
+            utils.find_resource,
+            self.manager,
+            self.name,
+        )
+        self.assertEqual(
+            "No lego with a name or ID of 'legos' exists.", str(result)
+        )
         self.manager.get.assert_called_with(self.name)
         self.manager.find.assert_called_with(name=self.name)
 
     def test_find_resource_list_forbidden(self):
         self.manager.get = mock.Mock(side_effect=Exception('Boom!'))
         self.manager.find = mock.Mock(side_effect=Exception('Boom!'))
-        self.manager.list = mock.Mock(
-            side_effect=exceptions.Forbidden(403)
+        self.manager.list = mock.Mock(side_effect=exceptions.Forbidden(403))
+        self.assertRaises(
+            exceptions.Forbidden, utils.find_resource, self.manager, self.name
         )
-        self.assertRaises(exceptions.Forbidden,
-                          utils.find_resource,
-                          self.manager,
-                          self.name)
         self.manager.list.assert_called_with()
 
     def test_find_resource_find_no_unique(self):
         self.manager.get = mock.Mock(side_effect=Exception('Boom!'))
         self.manager.find = mock.Mock(side_effect=NoUniqueMatch())
-        result = self.assertRaises(exceptions.CommandError,
-                                   utils.find_resource,
-                                   self.manager,
-                                   self.name)
-        self.assertEqual("More than one lego exists with the name 'legos'.",
-                         str(result))
+        result = self.assertRaises(
+            exceptions.CommandError,
+            utils.find_resource,
+            self.manager,
+            self.name,
+        )
+        self.assertEqual(
+            "More than one lego exists with the name 'legos'.", str(result)
+        )
         self.manager.get.assert_called_with(self.name)
         self.manager.find.assert_called_with(name=self.name)
 
@@ -625,7 +653,9 @@ class TestFindResource(test_utils.TestCase):
             loaded=True,
         )
         self.manager.list = mock.Mock(
-            return_value=[silly_resource, ],
+            return_value=[
+                silly_resource,
+            ],
         )
         result = utils.find_resource(self.manager, self.name)
         self.assertEqual(silly_resource, result)
@@ -642,12 +672,13 @@ class TestFindResource(test_utils.TestCase):
             )
         )
         self.manager.list = mock.Mock(return_value=[])
-        result = self.assertRaises(exceptions.CommandError,
-                                   utils.find_resource,
-                                   self.manager,
-                                   self.name)
-        self.assertEqual("Could not find resource legos",
-                         str(result))
+        result = self.assertRaises(
+            exceptions.CommandError,
+            utils.find_resource,
+            self.manager,
+            self.name,
+        )
+        self.assertEqual("Could not find resource legos", str(result))
         self.manager.get.assert_called_with(self.name)
         self.manager.find.assert_called_with(name=self.name)
 
@@ -670,34 +701,39 @@ class TestFindResource(test_utils.TestCase):
             {'id': 'abcde', 'name': self.name},
             loaded=True,
         )
-        self.manager.list = mock.Mock(return_value=[silly_resource,
-                                                    silly_resource_same])
-        result = self.assertRaises(exceptions.CommandError,
-                                   utils.find_resource,
-                                   self.manager,
-                                   self.name)
-        self.assertEqual("More than one resource exists "
-                         "with the name or ID 'legos'.", str(result))
+        self.manager.list = mock.Mock(
+            return_value=[silly_resource, silly_resource_same]
+        )
+        result = self.assertRaises(
+            exceptions.CommandError,
+            utils.find_resource,
+            self.manager,
+            self.name,
+        )
+        self.assertEqual(
+            "More than one resource exists " "with the name or ID 'legos'.",
+            str(result),
+        )
         self.manager.get.assert_called_with(self.name)
         self.manager.find.assert_called_with(name=self.name)
 
     def test_format_dict(self):
         expected = "a='b', c='d', e='f'"
-        self.assertEqual(expected,
-                         utils.format_dict({'a': 'b', 'c': 'd', 'e': 'f'}))
-        self.assertEqual(expected,
-                         utils.format_dict({'e': 'f', 'c': 'd', 'a': 'b'}))
+        self.assertEqual(
+            expected, utils.format_dict({'a': 'b', 'c': 'd', 'e': 'f'})
+        )
+        self.assertEqual(
+            expected, utils.format_dict({'e': 'f', 'c': 'd', 'a': 'b'})
+        )
         self.assertIsNone(utils.format_dict(None))
 
     def test_format_dict_recursive(self):
         expected = "a='b', c.1='d', c.2=''"
         self.assertEqual(
-            expected,
-            utils.format_dict({'a': 'b', 'c': {'1': 'd', '2': ''}})
+            expected, utils.format_dict({'a': 'b', 'c': {'1': 'd', '2': ''}})
         )
         self.assertEqual(
-            expected,
-            utils.format_dict({'c': {'1': 'd', '2': ''}, 'a': 'b'})
+            expected, utils.format_dict({'c': {'1': 'd', '2': ''}, 'a': 'b'})
         )
         self.assertIsNone(utils.format_dict(None))
 
@@ -715,7 +751,7 @@ class TestFindResource(test_utils.TestCase):
                         'b2': 'D',
                     },
                 }
-            )
+            ),
         )
         self.assertEqual(
             expected,
@@ -730,45 +766,64 @@ class TestFindResource(test_utils.TestCase):
                     },
                     'a1': 'A',
                 }
-            )
+            ),
         )
 
     def test_format_dict_of_list(self):
         expected = "a=a1, a2; b=b1, b2; c=c1, c2; e="
-        self.assertEqual(expected,
-                         utils.format_dict_of_list({'a': ['a2', 'a1'],
-                                                    'b': ['b2', 'b1'],
-                                                    'c': ['c1', 'c2'],
-                                                    'd': None,
-                                                    'e': []})
-                         )
-        self.assertEqual(expected,
-                         utils.format_dict_of_list({'c': ['c1', 'c2'],
-                                                    'a': ['a2', 'a1'],
-                                                    'b': ['b2', 'b1'],
-                                                    'e': []})
-                         )
+        self.assertEqual(
+            expected,
+            utils.format_dict_of_list(
+                {
+                    'a': ['a2', 'a1'],
+                    'b': ['b2', 'b1'],
+                    'c': ['c1', 'c2'],
+                    'd': None,
+                    'e': [],
+                }
+            ),
+        )
+        self.assertEqual(
+            expected,
+            utils.format_dict_of_list(
+                {
+                    'c': ['c1', 'c2'],
+                    'a': ['a2', 'a1'],
+                    'b': ['b2', 'b1'],
+                    'e': [],
+                }
+            ),
+        )
         self.assertIsNone(utils.format_dict_of_list(None))
 
     def test_format_dict_of_list_with_separator(self):
         expected = "a=a1, a2\nb=b1, b2\nc=c1, c2\ne="
-        self.assertEqual(expected,
-                         utils.format_dict_of_list({'a': ['a2', 'a1'],
-                                                    'b': ['b2', 'b1'],
-                                                    'c': ['c1', 'c2'],
-                                                    'd': None,
-                                                    'e': []},
-                                                   separator='\n')
-                         )
-        self.assertEqual(expected,
-                         utils.format_dict_of_list({'c': ['c1', 'c2'],
-                                                    'a': ['a2', 'a1'],
-                                                    'b': ['b2', 'b1'],
-                                                    'e': []},
-                                                   separator='\n')
-                         )
-        self.assertIsNone(utils.format_dict_of_list(None,
-                                                    separator='\n'))
+        self.assertEqual(
+            expected,
+            utils.format_dict_of_list(
+                {
+                    'a': ['a2', 'a1'],
+                    'b': ['b2', 'b1'],
+                    'c': ['c1', 'c2'],
+                    'd': None,
+                    'e': [],
+                },
+                separator='\n',
+            ),
+        )
+        self.assertEqual(
+            expected,
+            utils.format_dict_of_list(
+                {
+                    'c': ['c1', 'c2'],
+                    'a': ['a2', 'a1'],
+                    'b': ['b2', 'b1'],
+                    'e': [],
+                },
+                separator='\n',
+            ),
+        )
+        self.assertIsNone(utils.format_dict_of_list(None, separator='\n'))
 
     def test_format_list(self):
         expected = 'a, b, c'
@@ -795,35 +850,43 @@ class TestFindResource(test_utils.TestCase):
 
 
 class TestAssertItemEqual(test_utils.TestCommand):
-
     def test_assert_normal_item(self):
         expected = ['a', 'b', 'c']
         actual = ['a', 'b', 'c']
         self.assertItemEqual(expected, actual)
 
     def test_assert_item_with_formattable_columns(self):
-        expected = [format_columns.DictColumn({'a': 1, 'b': 2}),
-                    format_columns.ListColumn(['x', 'y', 'z'])]
-        actual = [format_columns.DictColumn({'a': 1, 'b': 2}),
-                  format_columns.ListColumn(['x', 'y', 'z'])]
+        expected = [
+            format_columns.DictColumn({'a': 1, 'b': 2}),
+            format_columns.ListColumn(['x', 'y', 'z']),
+        ]
+        actual = [
+            format_columns.DictColumn({'a': 1, 'b': 2}),
+            format_columns.ListColumn(['x', 'y', 'z']),
+        ]
         self.assertItemEqual(expected, actual)
 
     def test_assert_item_different_length(self):
         expected = ['a', 'b', 'c']
         actual = ['a', 'b']
-        self.assertRaises(AssertionError,
-                          self.assertItemEqual, expected, actual)
+        self.assertRaises(
+            AssertionError, self.assertItemEqual, expected, actual
+        )
 
     def test_assert_item_formattable_columns_vs_legacy_formatter(self):
-        expected = [format_columns.DictColumn({'a': 1, 'b': 2}),
-                    format_columns.ListColumn(['x', 'y', 'z'])]
-        actual = [utils.format_dict({'a': 1, 'b': 2}),
-                  utils.format_list(['x', 'y', 'z'])]
-        self.assertRaises(AssertionError,
-                          self.assertItemEqual, expected, actual)
+        expected = [
+            format_columns.DictColumn({'a': 1, 'b': 2}),
+            format_columns.ListColumn(['x', 'y', 'z']),
+        ]
+        actual = [
+            utils.format_dict({'a': 1, 'b': 2}),
+            utils.format_list(['x', 'y', 'z']),
+        ]
+        self.assertRaises(
+            AssertionError, self.assertItemEqual, expected, actual
+        )
 
     def test_assert_item_different_formattable_columns(self):
-
         class ExceptionColumn(cliff_columns.FormattableColumn):
             def human_readable(self):
                 raise Exception('always fail')
@@ -833,18 +896,80 @@ class TestAssertItemEqual(test_utils.TestCommand):
         # AssertionError is a subclass of Exception
         # so raising AssertionError ensures ExceptionColumn.human_readable()
         # is not called.
-        self.assertRaises(AssertionError,
-                          self.assertItemEqual, expected, actual)
+        self.assertRaises(
+            AssertionError, self.assertItemEqual, expected, actual
+        )
 
     def test_assert_list_item(self):
         expected = [
             ['a', 'b', 'c'],
-            [format_columns.DictColumn({'a': 1, 'b': 2}),
-             format_columns.ListColumn(['x', 'y', 'z'])]
+            [
+                format_columns.DictColumn({'a': 1, 'b': 2}),
+                format_columns.ListColumn(['x', 'y', 'z']),
+            ],
         ]
         actual = [
             ['a', 'b', 'c'],
-            [format_columns.DictColumn({'a': 1, 'b': 2}),
-             format_columns.ListColumn(['x', 'y', 'z'])]
+            [
+                format_columns.DictColumn({'a': 1, 'b': 2}),
+                format_columns.ListColumn(['x', 'y', 'z']),
+            ],
         ]
         self.assertListItemEqual(expected, actual)
+
+
+class TestSDKUtils(test_utils.TestCase):
+    def setUp(self):
+        super(TestSDKUtils, self).setUp()
+
+    def _test_get_osc_show_columns_for_sdk_resource(
+        self,
+        sdk_resource,
+        column_map,
+        expected_display_columns,
+        expected_attr_columns,
+    ):
+        (
+            display_columns,
+            attr_columns,
+        ) = utils.get_osc_show_columns_for_sdk_resource(
+            sdk_resource, column_map
+        )
+        self.assertEqual(expected_display_columns, display_columns)
+        self.assertEqual(expected_attr_columns, attr_columns)
+
+    def test_get_osc_show_columns_for_sdk_resource_empty(self):
+        self._test_get_osc_show_columns_for_sdk_resource(
+            {}, {}, tuple(), tuple()
+        )
+
+    def test_get_osc_show_columns_for_sdk_resource_empty_map(self):
+        self._test_get_osc_show_columns_for_sdk_resource(
+            {'foo': 'foo1'}, {}, ('foo',), ('foo',)
+        )
+
+    def test_get_osc_show_columns_for_sdk_resource_empty_data(self):
+        self._test_get_osc_show_columns_for_sdk_resource(
+            {}, {'foo': 'foo_map'}, ('foo_map',), ('foo_map',)
+        )
+
+    def test_get_osc_show_columns_for_sdk_resource_map(self):
+        self._test_get_osc_show_columns_for_sdk_resource(
+            {'foo': 'foo1'}, {'foo': 'foo_map'}, ('foo_map',), ('foo',)
+        )
+
+    def test_get_osc_show_columns_for_sdk_resource_map_dup(self):
+        self._test_get_osc_show_columns_for_sdk_resource(
+            {'foo': 'foo1', 'foo_map': 'foo1'},
+            {'foo': 'foo_map'},
+            ('foo_map',),
+            ('foo',),
+        )
+
+    def test_get_osc_show_columns_for_sdk_resource_map_full(self):
+        self._test_get_osc_show_columns_for_sdk_resource(
+            {'foo': 'foo1', 'bar': 'bar1'},
+            {'foo': 'foo_map', 'new': 'bar'},
+            ('bar', 'foo_map'),
+            ('bar', 'foo'),
+        )
